// Required Import elements for D3
import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  max
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => { 
// labeling X axis data   
  const xValue = d => d.Year; 
  const xAxisLabel = 'Years';
// labeling Y axis data 
  const yValue = d => d.sales;
  const yAxisLabel = 'Sales';
  
  const margin = { top: 20, right: 20, bottom: 38, left: 130 };//mm manière que CSS
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top-20 - margin.bottom-30;
  
  // adding data to x axis 
  const xScale = scaleTime()
    .domain(extent(data, xValue)) 
    .range([0, innerWidth]) 
    .nice(); //round values out
  
// adding data to y axis  
  const yScale = scaleLinear()
    .domain([0, max(data, yValue )])
    .range([innerHeight, 0])
    .nice();

// describing the svg element  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(15);
  	
  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -90)
      .attr('x', -innerHeight / 3)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 80)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);

// desining and adding line to svg
  
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)));
  
  g.append('path')
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data))
};

// Loading and Parsing CSV data
csv('https://gist.githubusercontent.com/Kiran3295/fb9834416a61f85946f2e081beaab2bd/raw/fb1b40125d16974c4ff190d986b7874475b4fb04/salesdata.csv')
  .then(data => {
    data.forEach(d => {
    	d.sales = +d.sales;
//Format to get year
      d.Year = d3.timeParse("%Y-%m-%d")(d.Year);
    });

    render(data);
  })